@@ -26,7 +26,7 @@ class FinanceService:
     def query_head_bills(self, shop_id, query):
         """
         查询总店账单
-        :param shopId:饿了么店总店店铺id
+        :param shopId:饿了么总店店铺id
         :param query:查询条件
         """
         return self.__client.call("eleme.finance.queryHeadBills", {"shopId": shop_id, "query": query})
@@ -34,7 +34,7 @@ class FinanceService:
     def query_head_orders(self, shop_id, query):
         """
         查询总店订单
-        :param shopId:饿了么店总店店铺id
+        :param shopId:饿了么总店店铺id
         :param query:查询条件
         """
         return self.__client.call("eleme.finance.queryHeadOrders", {"shopId": shop_id, "query": query})
@@ -42,7 +42,7 @@ class FinanceService:
     def query_branch_bills(self, shop_id, query):
         """
         查询分店账单
-        :param shopId:饿了么店总店店铺id
+        :param shopId:饿了么分店店铺id
         :param query:查询条件
         """
         return self.__client.call("eleme.finance.queryBranchBills", {"shopId": shop_id, "query": query})
@@ -50,7 +50,7 @@ class FinanceService:
     def query_branch_orders(self, shop_id, query):
         """
         查询分店订单
-        :param shopId:饿了么店总店店铺id
+        :param shopId:饿了么分店店铺id
         :param query:查询条件
         """
         return self.__client.call("eleme.finance.queryBranchOrders", {"shopId": shop_id, "query": query})
@@ -58,7 +58,7 @@ class FinanceService:
     def get_order(self, shop_id, order_id):
         """
         查询订单
-        :param shopId:饿了么店总店店铺id
+        :param shopId:饿了么店铺id
         :param orderId:订单id
         """
         return self.__client.call("eleme.finance.getOrder", {"shopId": shop_id, "orderId": order_id})
